@@ -90,6 +90,7 @@ def sample_to_dataframe(sample: Dict) -> pd.DataFrame:
 def normalize_sample(sample: Dict) -> Dict:
     if "files" not in sample:
         return {
-            "files": [sample.copy()]
+            "files": [sample.copy()],
+            **sample.copy()
         }
     return sample
